@@ -14,13 +14,20 @@ Implements a standard toolbar.
 # a new connection for each request). Up to (and including) version 2.3b1,
 # Python would not grant time to other threads while blocking inside
 # getaddrinfo(). This has been fixed *after* 2.3b1 was released. (jvr)
-
-from Cocoa import *
+import objc
+import Cocoa
 
 from threading import Thread
-from Queue import Queue
+try:
+    from Queue import Queue
+except ImportError:
+    from queue import Queue
+
+try:
+    from xmlrpclib import ServerProxy
+except ImportError:
+    from xmlrpc.client import ServerProxy
 
-import xmlrpclib
 import sys
 import types
 import string
@@ -43,7 +50,7 @@ def addToolbarItem(aController, anIdentifier, aLabel, aPaletteLabel,
     implementation of aController.  It should be refactored into a
     generically useful toolbar management untility.
     """
-    toolbarItem = NSToolbarItem.alloc().initWithItemIdentifier_(anIdentifier)
+    toolbarItem = Cocoa.NSToolbarItem.alloc().initWithItemIdentifier_(anIdentifier)
 
     toolbarItem.setLabel_(aLabel)
     toolbarItem.setPaletteLabel_(aPaletteLabel)
@@ -52,7 +59,7 @@ def addToolbarItem(aController, anIdentifier, aLabel, aPaletteLabel,
     if anAction:
         toolbarItem.setAction_(anAction)
 
-    if type(anItemContent) == NSImage:
+    if type(anItemContent) == Cocoa.NSImage:
         toolbarItem.setImage_(anItemContent)
     else:
         toolbarItem.setView_(anItemContent)
@@ -63,7 +70,7 @@ def addToolbarItem(aController, anIdentifier, aLabel, aPaletteLabel,
         toolbarItem.setMaxSize_( maxSize )
 
     if aMenu:
-        menuItem = NSMenuItem.alloc().init()
+        menuItem = Cocoa.NSMenuItem.alloc().init()
         menuItem.setSubmenu_(aMenu)
         menuItem.setTitle_( aMenu.title() )
         toolbarItem.setMenuFormRepresentation_(menuItem)
@@ -97,7 +104,7 @@ class WorkerThread(Thread):
             if work is None or not self.working:
                 break
             func, args, kwargs = work
-            pool = NSAutoreleasePool.alloc().init()
+            pool = Cocoa.NSAutoreleasePool.alloc().init()
             try:
                 func(*args, **kwargs)
             finally:
@@ -107,7 +114,7 @@ class WorkerThread(Thread):
                 del pool
 
 
-class WSTConnectionWindowController(NSWindowController):
+class WSTConnectionWindowController(Cocoa.NSWindowController):
     methodDescriptionTextView = objc.IBOutlet()
     methodsTable = objc.IBOutlet()
     progressIndicator = objc.IBOutlet()
@@ -162,7 +169,7 @@ class WSTConnectionWindowController(NSWindowController):
         self.retain() # balanced by autorelease() in windowWillClose_
 
         self.statusTextField.setStringValue_("No host specified.")
-        self.progressIndicator.setStyle_(NSProgressIndicatorSpinningStyle)
+        self.progressIndicator.setStyle_(Cocoa.NSProgressIndicatorSpinningStyle)
         self.progressIndicator.setDisplayedWhenStopped_(False)
 
         self.createToolbar()
@@ -186,7 +193,7 @@ class WSTConnectionWindowController(NSWindowController):
         """
         Creates and configures the toolbar to be used by the window.
         """
-        toolbar = NSToolbar.alloc().initWithIdentifier_("WST Connection Window")
+        toolbar = Cocoa.NSToolbar.alloc().initWithIdentifier_("WST Connection Window")
         toolbar.setDelegate_(self)
         toolbar.setAllowsUserCustomization_(True)
         toolbar.setAutosavesConfiguration_(True)
@@ -195,7 +202,7 @@ class WSTConnectionWindowController(NSWindowController):
 
         self.window().setToolbar_(toolbar)
 
-        lastURL = NSUserDefaults.standardUserDefaults().stringForKey_("LastURL")
+        lastURL = Cocoa.NSUserDefaults.standardUserDefaults().stringForKey_("LastURL")
         if lastURL and len(lastURL):
             self.urlTextField.setStringValue_(lastURL)
 
@@ -207,29 +214,29 @@ class WSTConnectionWindowController(NSWindowController):
         """
         addToolbarItem(self, kWSTReloadContentsToolbarItemIdentifier,
                        "Reload", "Reload", "Reload Contents", None,
-                       "reloadVisibleData:", NSImage.imageNamed_("Reload"), None)
+                       "reloadVisibleData:", Cocoa.NSImage.imageNamed_("Reload"), None)
         addToolbarItem(self, kWSTPreferencesToolbarItemIdentifier,
                        "Preferences", "Preferences", "Show Preferences", None,
-                       "orderFrontPreferences:", NSImage.imageNamed_("Preferences"), None)
+                       "orderFrontPreferences:", Cocoa.NSImage.imageNamed_("Preferences"), None)
         addToolbarItem(self, kWSTUrlTextFieldToolbarItemIdentifier,
                        "URL", "URL", "Server URL", None, None, self.urlTextField, None)
 
         self._toolbarDefaultItemIdentifiers = [
             kWSTReloadContentsToolbarItemIdentifier,
             kWSTUrlTextFieldToolbarItemIdentifier,
-            NSToolbarSeparatorItemIdentifier,
-            NSToolbarCustomizeToolbarItemIdentifier,
+            Cocoa.NSToolbarSeparatorItemIdentifier,
+            Cocoa.NSToolbarCustomizeToolbarItemIdentifier,
         ]
 
         self._toolbarAllowedItemIdentifiers = [
             kWSTReloadContentsToolbarItemIdentifier,
             kWSTUrlTextFieldToolbarItemIdentifier,
-            NSToolbarSeparatorItemIdentifier,
-            NSToolbarSpaceItemIdentifier,
-            NSToolbarFlexibleSpaceItemIdentifier,
-            NSToolbarPrintItemIdentifier,
+            Cocoa.NSToolbarSeparatorItemIdentifier,
+            Cocoa.NSToolbarSpaceItemIdentifier,
+            Cocoa.NSToolbarFlexibleSpaceItemIdentifier,
+            Cocoa.NSToolbarPrintItemIdentifier,
             kWSTPreferencesToolbarItemIdentifier,
-            NSToolbarCustomizeToolbarItemIdentifier,
+            Cocoa.NSToolbarCustomizeToolbarItemIdentifier,
         ]
 
     def toolbarDefaultItemIdentifiers_(self, anIdentifier):
@@ -256,7 +263,7 @@ class WSTConnectionWindowController(NSWindowController):
         Effectively makes a copy of the cached reference instance of
         the toolbar item identified by itemIdentifier.
         """
-        newItem = NSToolbarItem.alloc().initWithItemIdentifier_(itemIdentifier)
+        newItem = Cocoa.NSToolbarItem.alloc().initWithItemIdentifier_(itemIdentifier)
         item = self._toolbarItems[itemIdentifier]
 
         newItem.setLabel_( item.label() )
@@ -327,15 +334,15 @@ class WSTConnectionWindowController(NSWindowController):
             return
 
         self.window().setTitle_(url)
-        NSUserDefaults.standardUserDefaults().setObject_forKey_(url, "LastURL")
+        Cocoa.NSUserDefaults.standardUserDefaults().setObject_forKey_(url, "LastURL")
 
         self.setStatusTextFieldMessage_("Retrieving method list...")
         self.startWorking()
         self._workerThread.scheduleWork(self.getMethods, url)
 
     def getMethods(self, url):
-        self._server = xmlrpclib.ServerProxy(url)
-        pool = NSAutoreleasePool.alloc().init()  # use an extra pool to get rid of intermediates
+        self._server = ServerProxy(url)
+        pool = Cocoa.NSAutoreleasePool.alloc().init()  # use an extra pool to get rid of intermediates
         try:
             self._methods = self._server.listMethods()
             self._methodPrefix = ""
@@ -370,7 +377,7 @@ class WSTConnectionWindowController(NSWindowController):
         for aMethod in self._methods:
             if self._windowIsClosing:
                 return
-            pool = NSAutoreleasePool.alloc().init()  # use an extra pool to get rid of intermediates
+            pool = Cocoa.NSAutoreleasePool.alloc().init()  # use an extra pool to get rid of intermediates
             index = index + 1
             if not (index % 5):
                 self.reloadData()
