@@ -1,3 +1,4 @@
+#define PY_SSIZE_T_CLEAN
 #include <Python.h>
 #include "pyobjc-api.h"
 
@@ -14,6 +15,7 @@
 #include "_AppKit_nsquickdrawview.m"
 #include "_AppKit_nsview.m"
 #include "_AppKit_nswindow.m"
+#include "_AppKit_protocols.m"
 
 
 static PyMethodDef mod_methods[] = {
