@@ -6,10 +6,10 @@
 
 #import <AppKit/AppKit.h>
 
-static PyObject* 
+static PyObject*
 objc_NSApplicationMain(
-	PyObject* self __attribute__((__unused__)), 
-	PyObject* args, 
+	PyObject* self __attribute__((__unused__)),
+	PyObject* args,
 	PyObject* kwds)
 {
 static	char* keywords[] = { "argv", NULL };
@@ -26,7 +26,7 @@ static	char* keywords[] = { "argv", NULL };
 	}
 
 	if (!PySequence_Check(arglist)) {
-		PyErr_SetString(PyExc_TypeError, 
+		PyErr_SetString(PyExc_TypeError,
 			"NSApplicationMain: need list of strings as argument");
 		return NULL;
 	}
@@ -45,7 +45,7 @@ static	char* keywords[] = { "argv", NULL };
 			goto error_cleanup;
 		}
 		if (PyUnicode_Check(v)) {
-			PyObject* bytes = PyUnicode_AsEncodedString(v, 
+			PyObject* bytes = PyUnicode_AsEncodedString(v,
 					NULL, NULL);
 			if (!bytes) {
 				goto error_cleanup;
@@ -56,7 +56,7 @@ static	char* keywords[] = { "argv", NULL };
 			argv[i] = strdup(PyString_AsString(v));
 #endif
 		} else {
-			PyErr_SetString(PyExc_TypeError, 
+			PyErr_SetString(PyExc_TypeError,
 				"NSApplicationMain: need list of strings "
 				"as argument");
 			goto error_cleanup;
@@ -73,6 +73,7 @@ static	char* keywords[] = { "argv", NULL };
 
 	PyObjC_DURING
 		res = NSApplicationMain(argc, (const char**)argv);
+
 	PyObjC_HANDLER
 		PyObjCErr_FromObjC(localException);
 		res = -1;
@@ -108,5 +109,5 @@ error_cleanup:
 		"NSApplicationMain", 				\
 		(PyCFunction)objc_NSApplicationMain, 		\
 		METH_VARARGS|METH_KEYWORDS, 			\
-		"int NSApplicationMain(int argc, const char *argv[]);" \
+		"NSApplicationMain(arg0, arg1)\n\nint NSApplicationMain(int argc, const char *argv[]);" \
 	},
