@@ -8,11 +8,8 @@
  * using the linker due to limitations in pyobjc-api.h
  */
 
-#include "_Foundation_NSDecimal.m"
 #include "_Foundation_NSInvocation.m"
-#include "_Foundation_data.m"
 #include "_Foundation_netservice.m"
-#include "_Foundation_nscoder.m"
 #include "_Foundation_string.m"
 #include "_Foundation_typecode.m"
 #include "_Foundation_protocols.m"
@@ -34,11 +31,8 @@ PyObjC_MODULE_INIT(_Foundation)
 
 	if (PyObjC_ImportAPI(m) == -1) PyObjC_INITERROR();
 
-	if (setup_nsdecimal(m) == -1) PyObjC_INITERROR();
 	if (setup_nsinvocation(m) == -1) PyObjC_INITERROR();
-	if (setup_nsdata(m) == -1) PyObjC_INITERROR();
 	if (setup_nsnetservice(m) == -1) PyObjC_INITERROR();
-	if (setup_nscoder(m) == -1) PyObjC_INITERROR();
 	if (setup_nssstring(m) == -1) PyObjC_INITERROR();
 
 	PyObjC_INITDONE();
