@@ -2,6 +2,11 @@ from PyObjCTools.TestSupport import *
 import AppKit
 import objc
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class ContantTest (TestCase):
 
     def testNSFloatingWindowLevel(self):
@@ -11,7 +16,7 @@ class ContantTest (TestCase):
         self.assert_(isinstance(AppKit.NSFloatingWindowLevel, int))
 
     def testNSAnyEventMask(self):
-        self.assertEqual(AppKit.NSAnyEventMask, -1)
+        self.assertEqual(AppKit.NSAnyEventMask, AppKit.NSUIntegerMax)
 
     def testNSViewFrameDidChangeNotification(self):
         self.assert_(hasattr(AppKit, 'NSViewFrameDidChangeNotification'))
@@ -19,7 +24,7 @@ class ContantTest (TestCase):
 
     def testNSUpArrowFunctionKey(self):
         self.assert_(hasattr(AppKit, 'NSUpArrowFunctionKey'))
-        self.assert_(isinstance(AppKit.NSUpArrowFunctionKey, unicode))
+        self.assertIsInstance(AppKit.NSUpArrowFunctionKey, unicode)
 
 if __name__ == "__main__":
     main()
