@@ -1,6 +1,11 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSAccessibilityHelper (NSObject):
     def accessibilityIsAttributeSettable_(self, arg):
         return 1
@@ -48,6 +53,7 @@ class TestNSAccessibility (TestCase):
 
         v = NSAccessibilityPostNotification(b, "hello")
         self.assertIs(v, None)
+
     def testConstants(self):
         self.assertIsInstance(NSAccessibilityErrorCodeExceptionInfo, unicode)
         self.assertIsInstance(NSAccessibilityRoleAttribute, unicode)
@@ -336,5 +342,16 @@ class TestNSAccessibility (TestCase):
         self.assertIsInstance(NSAccessibilityContentListSubrole, unicode)
         self.assertIsInstance(NSAccessibilityDefinitionListSubrole, unicode)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(NSAccessibilityAutocorrectedTextAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityFullScreenButtonAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityPopoverRole, unicode)
+        self.assertIsInstance(NSAccessibilityFullScreenButtonSubrole, unicode)
+
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(NSAccessibilityExtrasMenuBarAttribute, unicode)
+
 if __name__ == "__main__":
     main()
