@@ -3,6 +3,11 @@ from PyObjCTools.TestSupport import *
 from Foundation import *
 import Foundation
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSBundle (TestCase):
     def testOutput(self):
         obj = NSBundle.mainBundle()
@@ -36,10 +41,12 @@ class TestNSBundle (TestCase):
 
         self.assertIsInstance(NSBundleDidLoadNotification, unicode)
         self.assertIsInstance(NSLoadedClasses, unicode)
+
     def testDefines(self):
         self.assertHasAttr(Foundation, 'NSLocalizedString')
         self.assertHasAttr(Foundation, 'NSLocalizedStringFromTable')
         self.assertHasAttr(Foundation, 'NSLocalizedStringFromTableInBundle')
         self.assertHasAttr(Foundation, 'NSLocalizedStringWithDefaultValue')
+
 if __name__ == "__main__":
     main()
