@@ -2,6 +2,11 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSConnectionHelper (NSObject):
     def makeNewConnection_sender_(self, a, b): return 1
     def connection_shouldMakeNewConnection_(self, a, b): return 1
@@ -14,6 +19,7 @@ class TestNSConnection (TestCase):
         self.assertIsInstance(NSConnectionDidDieNotification, unicode)
         self.assertIsInstance(NSFailedAuthenticationException, unicode)
         self.assertIsInstance(NSConnectionDidInitializeNotification, unicode)
+
     def testMethods(self):
         self.assertArgIsBOOL(NSConnection.setIndependentConversationQueueing_, 0)
         self.assertResultIsBOOL(NSConnection.independentConversationQueueing)
