@@ -49,10 +49,10 @@ class TestNSDecimalNumber (TestCase):
     def testNSScannerWithDecimal(self):
         v = NSScanner.alloc().initWithString_("55.23")
 
-        dec = NSDecimal()
-        o = v.scanDecimal_(dec)
+        o, dec = v.scanDecimal_(None)
+        self.assertIsInstance(dec, NSDecimal)
         self.assertIs(o, True)
-        self.assertEqual(dec.description(), '55.23')
+        self.assertEqual(str(dec), '55.23')
 
     def testMethods(self):
         self.assertArgIsBOOL(NSDecimalNumber.initWithMantissa_exponent_isNegative_, 2)
