@@ -2,6 +2,11 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSFileManagerHelper (NSObject):
     def fileManager_shouldProceedAfterError_(self, a, b): return 1
     def fileManager_willProcessPath_(self, a, b): pass
@@ -59,6 +64,7 @@ class TestNSFileManager (TestCase):
         self.assertIsInstance(NSFileSystemFreeSize, unicode)
         self.assertIsInstance(NSFileSystemNodes, unicode)
         self.assertIsInstance(NSFileSystemFreeNodes, unicode)
+
     @min_os_level('10.6')
     def testConstants10_6(self):
         self.assertEqual(NSVolumeEnumerationSkipHiddenVolumes, 1<<1)
@@ -71,6 +77,10 @@ class TestNSFileManager (TestCase):
         self.assertEqual(NSFileManagerItemReplacementUsingNewMetadataOnly, 1<<0)
         self.assertEqual(NSFileManagerItemReplacementWithoutDeletingBackupItem, 1<<1)
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(NSUbiquityIdentityDidChangeNotification, unicode)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertArgIsOut(NSFileManager.contentsOfDirectoryAtURL_includingPropertiesForKeys_options_error_, 3)
@@ -86,6 +96,42 @@ class TestNSFileManager (TestCase):
         self.assertResultIsBOOL(NSFileManager.removeItemAtURL_error_)
         self.assertArgIsOut(NSFileManager.removeItemAtURL_error_, 1)
 
+        self.assertArgIsBlock(NSFileManager.enumeratorAtURL_includingPropertiesForKeys_options_errorHandler_, 3, objc._C_NSBOOL + b'@@')
+
+        self.assertResultIsBOOL(NSFileManager.replaceItemAtURL_withItemAtURL_backupItemName_options_resultingItemURL_error_)
+        self.assertArgIsOut(NSFileManager.replaceItemAtURL_withItemAtURL_backupItemName_options_resultingItemURL_error_, 4)
+        self.assertArgIsOut(NSFileManager.replaceItemAtURL_withItemAtURL_backupItemName_options_resultingItemURL_error_, 5)
+
+
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(NSFileManager.createDirectoryAtURL_withIntermediateDirectories_attributes_error_)
+        self.assertArgIsBOOL(NSFileManager.createDirectoryAtURL_withIntermediateDirectories_attributes_error_, 1)
+        self.assertArgIsOut(NSFileManager.createDirectoryAtURL_withIntermediateDirectories_attributes_error_, 3)
+
+        self.assertResultIsBOOL(NSFileManager.createSymbolicLinkAtURL_withDestinationURL_error_)
+        self.assertArgIsOut(NSFileManager.createSymbolicLinkAtURL_withDestinationURL_error_, 2)
+
+        self.assertResultIsBOOL(NSFileManager.setUbiquitous_itemAtURL_destinationURL_error_)
+        self.assertArgIsBOOL(NSFileManager.setUbiquitous_itemAtURL_destinationURL_error_, 0)
+        self.assertArgIsOut(NSFileManager.setUbiquitous_itemAtURL_destinationURL_error_, 3)
+        self.assertResultIsBOOL(NSFileManager.isUbiquitousItemAtURL_)
+
+        self.assertResultIsBOOL(NSFileManager.startDownloadingUbiquitousItemAtURL_error_)
+        self.assertArgIsOut(NSFileManager.startDownloadingUbiquitousItemAtURL_error_, 1)
+
+        self.assertResultIsBOOL(NSFileManager.evictUbiquitousItemAtURL_error_)
+        self.assertArgIsOut(NSFileManager.evictUbiquitousItemAtURL_error_, 1)
+
+        self.assertArgIsOut(NSFileManager.URLForPublishingUbiquitousItemAtURL_expirationDate_error_, 1)
+        self.assertArgIsOut(NSFileManager.URLForPublishingUbiquitousItemAtURL_expirationDate_error_, 2)
+
+    @min_os_level('10.8')
+    def testMethods10_8(self):
+        self.assertResultIsBOOL(NSFileManager.trashItemAtURL_resultingItemURL_error_)
+        self.assertArgIsOut(NSFileManager.trashItemAtURL_resultingItemURL_error_, 1)
+        self.assertArgIsOut(NSFileManager.trashItemAtURL_resultingItemURL_error_, 2)
+
     def testOutput(self):
         obj = NSFileManager.defaultManager()
         m = obj.setAttributes_ofItemAtPath_error_.__metadata__()
@@ -200,11 +246,6 @@ class TestNSFileManager (TestCase):
         self.assertResultIsBOOL(NSFileManager.removeItemAtPath_error_)
         self.assertArgIsOut(NSFileManager.removeItemAtPath_error_, 1)
 
-        self.assertArgIsBlock(NSFileManager.enumeratorAtURL_includingPropertiesForKeys_options_errorHandler_, 3, objc._C_NSBOOL + b'@@')
-
-        self.assertResultIsBOOL(NSFileManager.replaceItemAtURL_withItemAtURL_backupItemName_options_resultingItemURL_error_)
-        self.assertArgIsOut(NSFileManager.replaceItemAtURL_withItemAtURL_backupItemName_options_resultingItemURL_error_, 4)
-        self.assertArgIsOut(NSFileManager.replaceItemAtURL_withItemAtURL_backupItemName_options_resultingItemURL_error_, 5)
 
     def testMethods(self):
         self.assertArgIsBOOL(NSFileManager.fileAttributesAtPath_traverseLink_, 1)
