@@ -2,6 +2,11 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSHTTPCookieStorage (TestCase):
     def testConstants(self):
         self.assertEqual(NSHTTPCookieAcceptPolicyAlways, 0)
@@ -10,5 +15,6 @@ class TestNSHTTPCookieStorage (TestCase):
 
         self.assertIsInstance(NSHTTPCookieManagerAcceptPolicyChangedNotification, unicode)
         self.assertIsInstance(NSHTTPCookieManagerCookiesChangedNotification, unicode)
+
 if __name__ == "__main__":
     main()
