@@ -1,6 +1,11 @@
 from PyObjCTools.TestSupport import *
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSLocale (TestCase):
     def testConstants(self):
         self.assertIsInstance(NSCurrentLocaleDidChangeNotification, unicode)
@@ -25,6 +30,7 @@ class TestNSLocale (TestCase):
         self.assertIsInstance(NSIslamicCalendar, unicode)
         self.assertIsInstance(NSIslamicCivilCalendar, unicode)
         self.assertIsInstance(NSJapaneseCalendar, unicode)
+
     @min_os_level('10.6')
     def testConstants10_6(self):
         self.assertIsInstance(NSLocaleCollatorIdentifier, unicode)
@@ -44,8 +50,5 @@ class TestNSLocale (TestCase):
         self.assertEqual(NSLocaleLanguageDirectionBottomToTop, kCFLocaleLanguageDirectionBottomToTop)
 
 
-
-
-
 if __name__ == "__main__":
     main()
