@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSOutlineViewHelper (NSObject):
     def outlineView_sizeToFitWidthOfColumn_(self, v, c): return 1
     def outlineView_shouldReorderColumn_toColumn_(self, v, c1, c2): return 1
@@ -38,6 +43,9 @@ class TestNSOutlineViewHelper (NSObject):
     def outlineView_shouldCollapseItem_(self, ov, it): return 1
     def outlineView_willDisplayOutlineCell_forTableColumn_item_(self, ov, c, tc, i): pass
 
+    def outlineView_draggingSession_willBeginAtPoint_(self, a, b, c): pass
+    def outlineView_draggingSession_endedAtPoint_(self, a, b, c): pass
+
 
 
 class TestNSOutlineView (TestCase):
@@ -104,6 +112,11 @@ class TestNSOutlineView (TestCase):
 
         self.assertResultIsBOOL(TestNSOutlineViewHelper.outlineView_shouldShowOutlineCellForItem_)
 
+    @min_os_level('10.7')
+    def testProtocols10_7(self):
+        self.assertArgHasType(TestNSOutlineViewHelper.outlineView_draggingSession_willBeginAtPoint_, 2, NSPoint.__typestr__)
+        self.assertArgHasType(TestNSOutlineViewHelper.outlineView_draggingSession_endedAtPoint_, 2, NSPoint.__typestr__)
+
 
 if __name__ == "__main__":
     main()
