@@ -15,22 +15,39 @@ class TestNSProcessInfo (TestCase):
         self.assertEqual(NSSunOSOperatingSystem, 6)
         self.assertEqual(NSOSF1OperatingSystem, 7)
 
+    @min_os_level('10.6')
     def testNSDisabledSuddenTermination(self):
         # annoyingly we cannot easily test if this has an effect, but
         # this at least guards against typos.
-        with NSDisabledSuddenTermination:
+        with NSDisabledSuddenTermination():
             pass
 
         class TestException (Exception):
             pass
         try:
-            with NSDisabledSuddenTermination:
+            with NSDisabledSuddenTermination():
                 raise TestException(1)
 
         except TestException:
             pass
 
 
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertArgIsBOOL(NSProcessInfo.setAutomaticTerminationSupportEnabled_, 0)
+        self.assertResultIsBOOL(NSProcessInfo.automaticTerminationSupportEnabled)
+
+        with NSDisabledAutomaticTermination("reason"):
+            pass
+
+        class TestException (Exception):
+            pass
+        try:
+            with NSDisabledAutomaticTermination("reason"):
+                raise TestException(1)
+
+        except TestException:
+            pass
 
 if __name__ == "__main__":
     main()
